@@ -1,3 +1,10 @@
+#
+# Copyright (c) Lightly AG and affiliates.
+# All rights reserved.
+#
+# This source code is licensed under the license found in the
+# LICENSE file in the root directory of this source tree.
+#
 from __future__ import annotations
 
 from pytorch_lightning import LightningModule
@@ -5,7 +12,7 @@ from torch import Tensor
 from torch.nn import Flatten
 
 from lightly_train._models.embedding_model import EmbeddingModel
-from lightly_train.types import SingleViewBatch
+from lightly_train.types import Batch
 
 
 class EmbeddingPredictor(LightningModule):
@@ -28,10 +35,8 @@ class EmbeddingPredictor(LightningModule):
         x = self.flatten(x)
         return x
 
-    def predict_step(
-        self, batch: SingleViewBatch, batch_idx: int
-    ) -> tuple[Tensor, list[str]]:
-        x = batch[0]
-        filenames = batch[-1]
+    def predict_step(self, batch: Batch, batch_idx: int) -> tuple[Tensor, list[str]]:
+        x = batch["views"][0]
+        filenames = batch["filename"]
         embeddings = self(x)
         return embeddings, filenames
