@@ -1,14 +1,19 @@
-from dataclasses import dataclass
+#
+# Copyright (c) Lightly AG and affiliates.
+# All rights reserved.
+#
+# This source code is licensed under the license found in the
+# LICENSE file in the root directory of this source tree.
+#
 
 from torch.optim.optimizer import Optimizer
 
-from lightly_train._configs.config import Config
+from lightly_train._configs.config import PydanticConfig
 from lightly_train._optim.optimizer_type import OptimizerType
 from lightly_train.types import ParamsT
 
 
-@dataclass
-class OptimizerArgs(Config):
+class OptimizerArgs(PydanticConfig):
     """Base class for optimizer arguments."""
 
     @staticmethod
