@@ -1,9 +1,18 @@
+#
+# Copyright (c) Lightly AG and affiliates.
+# All rights reserved.
+#
+# This source code is licensed under the license found in the
+# LICENSE file in the root directory of this source tree.
+#
 from datetime import datetime, timezone
 
 from lightly_train._checkpoint import (
     CheckpointLightlyTrain,
     CheckpointLightlyTrainModels,
 )
+from lightly_train._models.embedding_model import EmbeddingModel
+from lightly_train._transforms.transform import NormalizeArgs
 
 from . import helpers
 
@@ -13,15 +22,17 @@ class TestCheckpointInfo:
         date = datetime(
             year=2024, month=1, day=2, minute=3, second=4, tzinfo=timezone.utc
         )
-        model = helpers.get_model()
-        embedding_model = helpers.get_embedding_model(model=model)
+        wrapped_model = helpers.DummyCustomModel()
+        embedding_model = EmbeddingModel(wrapped_model=wrapped_model)
         info = CheckpointLightlyTrain(
             version="abc",
             date=date,
             models=CheckpointLightlyTrainModels(
-                model=model,
+                model=wrapped_model.get_model(),
+                wrapped_model=wrapped_model,
                 embedding_model=embedding_model,
             ),
+            normalize_args=NormalizeArgs(),
         )
 
         # Check that to_dict representation is correct.
@@ -30,9 +41,11 @@ class TestCheckpointInfo:
             "version": "abc",
             "date": "2024-01-02T00:03:04+00:00",
             "models": {
-                "model": model,
+                "model": wrapped_model.get_model(),
+                "wrapped_model": wrapped_model,
                 "embedding_model": embedding_model,
             },
+            "normalize_args": NormalizeArgs().to_dict(),
         }
 
         # Check that from_dict reconstruction is correct.
